@@ -2,7 +2,7 @@
     with elementary_test_results as (
         select * from {{ ref('elementary', 'elementary_test_results') }}
         {% if days_back %}
-            where {{ elementary.datediff(elementary.cast_as_timestamp('detected_at'), elementary.current_timestamp(), 'day') }} < {{ days_back }}
+            where {{ elementary.edr_datediff(elementary.edr_cast_as_timestamp('detected_at'), elementary.edr_current_timestamp(), 'day') }} < {{ days_back }}
         {% endif %}
     ),
 
@@ -10,6 +10,10 @@
         select * from {{ ref('elementary', 'dbt_tests') }}
     ),
 
+    dbt_models as (
+        select * from {{ ref('elementary', 'dbt_models') }}
+    ),
+
     first_time_test_occurred as (
         select 
             min(detected_at) as first_time_occurred,
@@ -57,10 +61,15 @@
         {# In old versions of elementary, elementary_test_results doesn't contain test_short_name, so we use dbt_test short_name. #}
         dbt_tests.short_name,
         elementary_test_results.test_alias,
+        elementary_test_results.failures,
         elementary_test_results.result_rows,
         dbt_tests.meta,
+        dbt_models.meta as model_meta,
+        dbt_models.tags as model_tags,
+        dbt_models.owner as model_owner,
         first_occurred.first_time_occurred as test_created_at
     from elementary_test_results
     join dbt_tests on elementary_test_results.test_unique_id = dbt_tests.unique_id
     left join first_time_test_occurred first_occurred on elementary_test_results.test_unique_id = first_occurred.test_unique_id
+    left join dbt_models on elementary_test_results.model_unique_id = dbt_models.unique_id
 {% endmacro %}
