@@ -1,6 +1,5 @@
-import ast
 import json
-from typing import List, Union
+from typing import Union
 
 
 def try_load_json(string_value: str):
@@ -18,10 +17,3 @@ def prettify_json_str_set(str_json_list: Union[str, list]) -> str:
     if isinstance(json_obj, list):
         return ", ".join(set(json_obj))
     return str_json_list
-
-
-def parse_str_to_list(string_value: str) -> List[str]:
-    try:
-        return ast.literal_eval(string_value)
-    except Exception:
-        return [part.strip() for part in string_value.split(",")]
